Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Amplify UI Builder.

Actions, resources, and condition keys for AWS Amplify UI Builder - Service Authorization Reference

# Actions, resources, and condition keys for AWS Amplify UI Builder

AWS Amplify UI Builder (service prefix: `amplifyuibuilder` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Amplify UI Builder
- Resource types defined by AWS Amplify UI Builder
- Condition keys for AWS Amplify UI Builder

## Actions defined by AWS Amplify UI Builder

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateComponent | Grants permission to create a component | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | amplify:GetApp amplifyuibuilder:GetComponent amplifyuibuilder:TagResource
CreateForm | Grants permission to create a form | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | amplify:GetApp amplifyuibuilder:GetForm amplifyuibuilder:TagResource amplifyuibuilder:UntagResource
CreateTheme | Grants permission to create a theme | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | amplify:GetApp amplifyuibuilder:GetTheme amplifyuibuilder:TagResource
DeleteComponent | Grants permission to delete a component | Write | ComponentResource* |  | amplify:GetApp amplifyuibuilder:UntagResource
DeleteForm | Grants permission to delete a form | Write | FormResource* |  | amplify:GetApp amplifyuibuilder:TagResource amplifyuibuilder:UntagResource
DeleteTheme | Grants permission to delete a theme | Write | ThemeResource* |  | amplify:GetApp amplifyuibuilder:UntagResource
ExchangeCodeForToken | Grants permission to exchange a code for a token | Write |  |  |
ExportComponents | Grants permission to export components | Read |  |  |
ExportForms | Grants permission to export forms | Read |  |  |
ExportThemes | Grants permission to export themes | Read |  |  |
GetCodegenJob | Grants permission to get an existing codegen job | Read | CodegenJobResource* |  | amplify:GetApp
GetComponent | Grants permission to get an existing component | Read | ComponentResource* |  | amplify:GetApp
GetForm | Grants permission to get an existing form | Read | FormResource* |  | amplify:GetApp
GetMetadata | Grants permission to get an existing metadata | Read |  |  |
GetTheme | Grants permission to get an existing theme | Read | ThemeResource* |  | amplify:GetApp
ListCodegenJobs | Grants permission to list codegen jobs | List |  |  | amplify:GetApp
ListComponents | Grants permission to list components | List |  |  | amplify:GetApp
ListForms | Grants permission to list forms | List |  |  | amplify:GetApp
ListTagsForResource | Grants permission to list tags for a specified Amazon Resource Name (ARN) | List | CodegenJobResource |  |
ComponentResource |  |
FormResource |  |
ThemeResource |  |
ListThemes | Grants permission to list themes | List |  |  | amplify:GetApp
PutMetadataFlag | Grants permission to put an existing metadata | Write |  |  |
RefreshToken | Grants permission to refresh an access token | Write |  |  |
ResetMetadataFlag | Grants permission to reset an existing metadata | Write |  |  |
StartCodegenJob | Grants permission to start a codegen job | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | amplify:GetApp
TagResource | Grants permission to tag the resource with a tag key and value | Tagging | CodegenJobResource |  |
ComponentResource |  |
FormResource |  |
ThemeResource |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to untag a resource with a specified Amazon Resource Name (ARN) | Tagging | CodegenJobResource |  |
ComponentResource |  |
FormResource |  |
ThemeResource |  |
| aws:TagKeys |
UpdateComponent | Grants permission to update a component | Write | ComponentResource* |  | amplify:GetApp amplifyuibuilder:TagResource amplifyuibuilder:UntagResource
UpdateForm | Grants permission to update a form | Write | FormResource* |  | amplify:GetApp amplifyuibuilder:GetForm amplifyuibuilder:TagResource amplifyuibuilder:UntagResource
UpdateTheme | Grants permission to update a theme | Write | ThemeResource* |  | amplify:GetApp amplifyuibuilder:GetTheme amplifyuibuilder:TagResource amplifyuibuilder:UntagResource

## Resource types defined by AWS Amplify UI Builder

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
CodegenJobResource | `arn:$ { Partition}:amplifyuibuilder:$ { Region}:$ { Account}:app/$ { AppId}/environment/$ { EnvironmentName}/codegen-jobs/$ { Id}` | amplifyuibuilder:CodegenJobResourceAppId amplifyuibuilder:CodegenJobResourceEnvironmentName amplifyuibuilder:CodegenJobResourceId aws:ResourceTag/${TagKey}
ComponentResource | `arn:$ { Partition}:amplifyuibuilder:$ { Region}:$ { Account}:app/$ { AppId}/environment/$ { EnvironmentName}/components/$ { Id}` | amplifyuibuilder:ComponentResourceAppId amplifyuibuilder:ComponentResourceEnvironmentName amplifyuibuilder:ComponentResourceId aws:ResourceTag/${TagKey}
FormResource | `arn:$ { Partition}:amplifyuibuilder:$ { Region}:$ { Account}:app/$ { AppId}/environment/$ { EnvironmentName}/forms/$ { Id}` | amplifyuibuilder:FormResourceAppId amplifyuibuilder:FormResourceEnvironmentName amplifyuibuilder:FormResourceId aws:ResourceTag/${TagKey}
ThemeResource | `arn:$ { Partition}:amplifyuibuilder:$ { Region}:$ { Account}:app/$ { AppId}/environment/$ { EnvironmentName}/themes/$ { Id}` | amplifyuibuilder:ThemeResourceAppId amplifyuibuilder:ThemeResourceEnvironmentName amplifyuibuilder:ThemeResourceId aws:ResourceTag/${TagKey}

## Condition keys for AWS Amplify UI Builder

AWS Amplify UI Builder defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
amplifyuibuilder:CodegenJobResourceAppId | Filters access by the app ID | String
amplifyuibuilder:CodegenJobResourceEnvironmentName | Filters access by the backend environment name | String
amplifyuibuilder:CodegenJobResourceId | Filters access by the codegen job ID | String
amplifyuibuilder:ComponentResourceAppId | Filters access by the app ID | String
amplifyuibuilder:ComponentResourceEnvironmentName | Filters access by the backend environment name | String
amplifyuibuilder:ComponentResourceId | Filters access by the component ID | String
amplifyuibuilder:FormResourceAppId | Filters access by the app ID | String
amplifyuibuilder:FormResourceEnvironmentName | Filters access by the backend environment name | String
amplifyuibuilder:FormResourceId | Filters access by the form ID | String
amplifyuibuilder:ThemeResourceAppId | Filters access by the app ID | String
amplifyuibuilder:ThemeResourceEnvironmentName | Filters access by the backend environment name | String
amplifyuibuilder:ThemeResourceId | Filters access by the theme ID | String
aws:RequestTag/${TagKey} | Filters access by the tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.